==> HinemosWebClient_src-1.0.0.tar.gz: HinemosWebClient_src-1.0.0/src/com/necsoft/hinemos/webclient/accesscontrol/servlet/LogoutServlet.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/
package com.necsoft.hinemos.webclient.accesscontrol.servlet;

import java.io.IOException;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.log4j.Logger;

import com.necsoft.hinemos.webclient.accesscontrol.util.LoginSessionManager;
import com.necsoft.hinemos.webclient.servlet.CommonServlet;

/**
 * Hinemosマネージャからログアウトするクラス
 * 
 * @version 1.0.0
 * @since 1.0.0
 **/
public class LogoutServlet extends HttpServlet {

    private static final long serialVersionUID = -7779138982488178793L;

    private static Logger m_log = Logger.getLogger(CommonServlet.class);

    /**
     * Handles the HTTP <code>GET</code> method.
     * 
     * @param request
     *            servlet request
     * @param response
     *            servlet response
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response) {

        // 中間変数を宣言
        HttpSession session = request.getSession(true);

        // サーバからログアウト
        LoginSessionManager.processLogout(session, false);

        // logout.jspにフォワードする
        try {
            response.sendRedirect(request.getContextPath() + "/login");
        } catch (IOException e) {
            m_log.error(e.getMessage());
        }
    }

    /**
     * Handles the HTTP <code>POST</code> method.
     * 
     * @param request
     *            servlet request
     * @param response
     *            servlet response
     */
    protected void doPost(HttpServletRequest request,
            HttpServletResponse response) {
        doGet(request, response);
    }
}

==> HinemosWebClient_src-2.0.0.tar.gz: HinemosWebClient_src-2.0.0/src/com/necsoft/hinemos/webclient/accesscontrol/servlet/LogoutServlet.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.accesscontrol.servlet;

import java.io.IOException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import com.necsoft.hinemos.webclient.accesscontrol.util.LoginSessionManager;

/**
 * Hinemosマネージャからログアウトするクラス
 * 
 * @version 1.0.0
 * @since 1.0.0
 **/
public class LogoutServlet extends HttpServlet {

    private static final long serialVersionUID = -7779138982488178793L;

    private static Logger m_log = Logger.getLogger(LogoutServlet.class);

    /**
     * Handles the HTTP <code>GET</code> method.
     * 
     * @param request
     *            servlet request
     * @param response
     *            servlet response
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response) {

        // 中間変数を宣言
        HttpSession session = request.getSession(true);

        // サーバからログアウト
        LoginSessionManager.processLogout(session, false);

        // logout.jspにフォワードする
        try {
            response.sendRedirect(request.getContextPath() + "/login");
        } catch (IOException e) {
            m_log.error(e.getMessage());
        }
    }

    /**
     * Handles the HTTP <code>POST</code> method.
     * 
     * @param request
     *            servlet request
     * @param response
     *            servlet response
     */
    protected void doPost(HttpServletRequest request,
            HttpServletResponse response) {
        doGet(request, response);
    }
}
